<?php
/**
 * This file represents an example of the code that themes would use to register
 * the required plugins.
 *
 * It is expected that theme authors would copy and paste this code into their
 * functions.php file, and amend to suit.
 *
 * @package	   TGM-Plugin-Activation
 * @subpackage Example
 * @version	   2.6.1
 * @author	   Thomas Griffin <thomas@thomasgriffinmedia.com>
 * @author	   Gary Jones <gamajo@gamajo.com>
 * @copyright  Copyright (c) 2012, Thomas Griffin
 * @license	   http://opensource.org/licenses/gpl-2.0.php GPL v2 or later
 * @link       https://github.com/thomasgriffin/TGM-Plugin-Activation
 */

/**
 * Include the TGM_Plugin_Activation class.
 */
require_once (get_template_directory().'/inc/class-tgm-plugin-activation.php');

add_action( 'tgmpa_register', 'zapto_register_plugins' );
/**
 * Register the required plugins for this theme.
 *
 * In this example, we register two plugins - one included with the TGMPA library
 * and one from the .org repo.
 *
 * The variable passed to tgmpa_register_plugins() should be an array of plugin
 * arrays.
 *
 * This function is hooked into tgmpa_init, which is fired within the
 * TGM_Plugin_Activation class constructor.
 */
function zapto_register_plugins() {

	/**
	 * Array of plugin arrays. Required keys are name and slug.
	 * If the source is NOT from the .org repo, then source is also required.
	 */
	$plugins = array(

		array(
            'name'      =>  esc_html__('WordPress Importer','zapto'),
            'slug'      => 'wordpress-importer',
            'required'  => true,
			'force_activation' => false,
        ),
		array(
            'name'      =>  esc_html__('Widget Importer & Exporter','zapto'),
            'slug'      => 'widget-importer-exporter',
            'required'  => true,
			'force_activation' => false,
        ),
		array(
            'name'      =>  esc_html__('Redux Framework','zapto'),
            'slug'      => 'redux-framework',
            'required'  => true,
			'force_activation' => false,
        ),
		array(
            'name'      => esc_html__('Contact Form 7','zapto'),
            'slug'      => 'contact-form-7',
            'required'  => false,
        ),
		
		array(
            'name'      => esc_html__('Meta Box','zapto'),
            'slug'      => 'meta-box',
            'required'  => false,
        ),
		
		array(
			'name'     				=> esc_html__('Zapto Toolkit','zapto'),
			'slug'     				=> 'zapto-toolkit',
			'source'   				=> get_stylesheet_directory(). '/inc/plugins/zapto-toolkit.zip',
			'required' 				=> true, 
			'version' 				=> '', 
			'force_activation' 		=> false, 
			'force_deactivation' 	=> false,
			'external_url' 			=> '',
		),
		array(
			'name'     				=> esc_html__('Visual Composer','zapto'),
			'slug'     				=> 'js_composer',
			'source'   				=> get_stylesheet_directory(). '/inc/plugins/js_composer.zip',
			'required' 				=> true, 
			'version' 				=> '', 
			'force_activation' 		=> false, 
			'force_deactivation' 	=> false,
			'external_url' 			=> '',
		),
		array(
			'name'     				=> esc_html__('TL VC Shortcodes','zapto'),
			'slug'     				=> 'tl-vc-shortcodes',
			'source'   				=> get_stylesheet_directory(). '/inc/plugins/tl-vc-shortcodes.zip',
			'required' 				=> true, 
			'version' 				=> '', 
			'force_activation' 		=> false, 
			'force_deactivation' 	=> false,
			'external_url' 			=> '',
		),
		
		
		
	);
	
	
	$theme_text_domain = 'zapto';

	/**
	 * Array of configuration settings. Amend each line as needed.
	 * If you want the default strings to be available under your own theme domain,
	 * leave the strings uncommented.
	 * Some of the strings are added into a sprintf, so see the comments at the
	 * end of each line for what each argument will be.
	 */
	$config = array(
		'domain'       		=> 'zapto',         	// Text domain - likely want to be the same as your theme.
		'default_path' 		=> '',                         	// Default absolute path to pre-packaged plugins
		'menu'         		=> 'install-required-plugins', 	// Menu slug
		'has_notices'      	=> true,                       	// Show admin notices or not
		'is_automatic'    	=> false,					   	// Automatically activate plugins after installation or not
		'message' 			=> '',							// Message to output right before the plugins table
		'strings'      		=> array(
			'page_title'                       			=> esc_html__( 'Install Required Plugins', 'zapto' ),
			'menu_title'                       			=> esc_html__( 'Install Plugins', 'zapto' ),
			'installing'                       			=> esc_html__( 'Installing Plugin: %s', 'zapto' ), // %1$s = plugin name
			'oops'                             			=> esc_html__( 'Something went wrong with the plugin API.', 'zapto' ),
			'notice_can_install_required'     			=> _n_noop( esc_html__('This theme requires the following plugin: %1$s.', 'zapto'), esc_html__('This theme requires the following plugins: %1$s.', 'zapto' )), // %1$s = plugin name(s)
			'notice_can_install_recommended'			=> _n_noop( esc_html__('This theme recommends the following plugin: %1$s.', 'zapto'), esc_html__('This theme recommends the following plugins: %1$s.', 'zapto' )), // %1$s = plugin name(s)
			'notice_cannot_install'  					=> _n_noop( esc_html__('Sorry, but you do not have the correct permissions to install the %s plugin. Contact the administrator of this site for help on getting the plugin installed.', 'zapto'), esc_html__('Sorry, but you do not have the correct permissions to install the %s plugins. Contact the administrator of this site for help on getting the plugins installed.', 'zapto' )), // %1$s = plugin name(s)
			'notice_can_activate_required'    			=> _n_noop( esc_html__('The following required plugin is currently inactive: %1$s.', 'zapto'), esc_html__('The following required plugins are currently inactive: %1$s.', 'zapto' )), // %1$s = plugin name(s)
			'notice_can_activate_recommended'			=> _n_noop( esc_html__('The following recommended plugin is currently inactive: %1$s.', 'zapto'), esc_html__('The following recommended plugins are currently inactive: %1$s.', 'zapto' )), // %1$s = plugin name(s)
			'notice_cannot_activate' 					=> _n_noop( esc_html__('Sorry, but you do not have the correct permissions to activate the %s plugin. Contact the administrator of this site for help on getting the plugin activated.', 'zapto'), esc_html__('Sorry, but you do not have the correct permissions to activate the %s plugins. Contact the administrator of this site for help on getting the plugins activated.', 'zapto' )), // %1$s = plugin name(s)
			'notice_ask_to_update' 						=> _n_noop( esc_html__('The following plugin needs to be updated to its latest version to ensure maximum compatibility with this theme: %1$s.', 'zapto'), esc_html__('The following plugins need to be updated to their latest version to ensure maximum compatibility with this theme: %1$s.', 'zapto' )), // %1$s = plugin name(s)
			'notice_cannot_update' 						=> _n_noop( esc_html__('Sorry, but you do not have the correct permissions to update the %s plugin. Contact the administrator of this site for help on getting the plugin updated.', 'zapto'), esc_html__('Sorry, but you do not have the correct permissions to update the %s plugins. Contact the administrator of this site for help on getting the plugins updated.', 'zapto' )), // %1$s = plugin name(s)
			'install_link' 					  			=> _n_noop( esc_html__('Begin installing plugin', 'zapto'), esc_html__('Begin installing plugins', 'zapto' )),
			'activate_link' 				  			=> _n_noop( esc_html__('Activate installed plugin', 'zapto'), esc_html__('Activate installed plugins', 'zapto' )),
			'return'                           			=> esc_html__( 'Return to Required Plugins Installer', 'zapto' ),
			'plugin_activated'                 			=> esc_html__( 'Plugin activated successfully.', 'zapto' ),
			'complete' 									=> esc_html__( 'All plugins installed and activated successfully. %s', 'zapto' ), // %1$s = dashboard link
			'nag_type'									=> 'updated' // Determines admin notice type - can only be 'updated' or 'error'
		)
	);

	tgmpa( $plugins, $config );

}