<?php

class zapto_post_list_widget extends WP_Widget{
	
  static function zapto_register_widget(){
	register_widget('zapto_post_list_widget');
  }
	
  function __construct(){
	  
    $widget_ops = array('classname' => 'post_list_widget', 'description' => 'Post Listing Widget' );
    parent::__construct('post_list_view', 'Zapto Post List Widget', $widget_ops);
  
  }/* end of zapto_post_list_widget function */

   function form($instance){
   
   $instance = wp_parse_args( (array) $instance, array( 'title' => '' ) );
   
	$zapto_title = $instance['title'];
	$zapto_post_num = isset( $instance['num_post'] ) ? esc_attr( $instance['num_post'] ) : '';
	$zapto_post_cat = isset( $instance['post_cat'] ) ? esc_attr( $instance['post_cat'] ) : '';
	$zapto_char_length = isset( $instance['excerpt_length'] ) ? esc_attr( $instance['excerpt_length'] ) : '';
	
?>	

	<p>
		<label for="<?php echo esc_attr($this->get_field_id('title')); ?>">
			<?php esc_html_e('Title:','zapto');?>  
			<input class="widefat"  id="<?php echo esc_attr($this->get_field_id('title')); ?>" name="<?php echo esc_attr($this->get_field_name('title')); ?>" type="text" value="<?php echo esc_attr($zapto_title); ?>" />
		</label>
  
	</p>

	<p>
		<label for="<?php echo esc_attr($this->get_field_id('post_cat')); ?>">
			<?php esc_html_e('Select Post Category:','zapto');?>  
			<select name="<?php echo esc_attr($this->get_field_name('post_cat'));?>" id="<?php echo esc_attr($this->get_field_id('post_cat')); ?>" class="widefat">
			<?php
			foreach ( zapto_get_category('category') as $category){ ?>
				<option <?php if(esc_attr($zapto_post_cat) == $category->slug){echo 'selected';}?> value="<?php echo esc_attr($category->slug);?>" >
				<?php echo esc_attr($category->name);?>
				</option>						
			<?php } ?>
			</select>
		</label>
	</p>
	
	<p>
		<label for="<?php echo esc_attr($this->get_field_id('num_post')); ?>">
			<?php esc_html_e('Number Of Post:','zapto');?>  
			<input class="widefat"  id="<?php echo esc_attr($this->get_field_id('num_post')); ?>" name="<?php echo esc_attr($this->get_field_name('num_post')); ?>" type="text" value="<?php echo esc_attr($zapto_post_num); ?>" />
		</label>
	</p>
	<p>
		<label for="<?php echo esc_attr($this->get_field_id('excerpt_length')); ?>">
			<?php esc_html_e('Excerpt Length:','zapto');?>  
			<input class="widefat"  id="<?php echo esc_attr($this->get_field_id('excerpt_length')); ?>" name="<?php echo esc_attr($this->get_field_name('excerpt_length')); ?>" type="text" value="<?php echo esc_attr($zapto_char_length); ?>" />
		</label>
	</p>

<?php
 
 }/*end of form function*/


	function update($new_instance, $old_instance)
    {
  
		$instance = $old_instance;
    
		$instance['title'] = $new_instance['title'];
		$instance['post_cat'] = $new_instance['post_cat'];	
		$instance['num_post'] = $new_instance['num_post'];
		$instance['excerpt_length'] = $new_instance['excerpt_length'];
    
		return $instance;
  
   }/*end of update function*/
 
	function widget($args, $instance){
		
		extract($args, EXTR_SKIP);
		
		$zapto_title = empty($instance['title']) ? ' ' : apply_filters('widget_title', $instance['title']);
		$zapto_post_cat = isset( $instance['post_cat'] ) ? esc_attr( $instance['post_cat'] ) : '';	
		$zapto_post_num = isset( $instance['num_post'] ) ? esc_attr( $instance['num_post'] ) : '';	
		$zapto_char_length = isset( $instance['excerpt_length'] ) ? esc_attr( $instance['excerpt_length'] ) : '';
		global $post;
		if(!empty($zapto_post_cat)){
			$term = get_term_by('name', $zapto_post_cat, 'category');
			$category_id = $term->term_id;
		}
		$args = array(	
			'posts_per_page' => $zapto_post_num,
			'post_type'	 => 'post',
			'tax_query' => array(
						array(
							'taxonomy' => 'category',
							'terms' => $category_id,
							'field' => 'term_id',
						)
					), 
			'post_status' => 'publish',
			'orderby' => 'comment_count',
			'ignore_sticky_posts' => 1
		);
		$zapto_query = new WP_Query($args);
		echo html_entity_decode($before_widget);
		if ($zapto_title <> ""){
			
			echo html_entity_decode($before_title);
			
			echo esc_attr($zapto_title);
			
			echo html_entity_decode($after_title);
		
		}
		if($zapto_query->have_posts()){ ?>
		<ul>
		<?php	
			while($zapto_query->have_posts()){
				$zapto_query->the_post();	
		?>	
			<li>
				<p>
				<?php 
					if(!empty($zapto_char_length)){
					echo substr(get_the_content(),0,$zapto_char_length);
					}else{
						echo esc_attr(get_the_content());
					}
				?>
				<br><span><?php esc_html_e('Posted by','zapto');?>
				<em><?php echo esc_attr(get_the_author_meta('nicename'));?></em></span>
				
				</p>
			</li>
		<?php					
			}/*endwhile loop*/
		}/*endif statemnt*/
		wp_reset_postdata();
		?>

		</ul>
		<?php 
	
		echo html_entity_decode($after_widget);
	
  }/* end of widget function */
  
 
 }/* end of class  zapto_post_list_widget*/
 add_action( 'widgets_init', array('zapto_post_list_widget', 'zapto_register_widget'));